@@ -69,7 +69,7 @@ if __name__ == '__main__':
     db_parser.add_argument('-p', help='Set password with address')
 
     args = parser.parse_args()
-    logger.info(args)
+    logger.debug(args)
 
     if args.subcommand == 'report':
         if args.code:
@@ -85,6 +85,7 @@ if __name__ == '__main__':
             pd.set_option('display.width', None)
             pd.set_option('display.max_colwidth', None)
             print(df)
+            print("Save to mongo database...")
             mongo2.EvalWithDate(client, datetime.datetime.today().strftime('%Y%m%d'))
 
     elif args.subcommand == 'spac':
@@ -93,7 +94,7 @@ if __name__ == '__main__':
                 noti.telegram_to(botname='eval',
                                  text=f'<<< code: {code} name: {name} price: {price} >>>')
         noti.telegram_to(botname='manager',
-                         text=f'>>> python {os.path.basename(os.path.realpath(__file__))} {args.cmd}')
+                         text=f'>>> python {os.path.basename(os.path.realpath(__file__))} {args.subcommand}')
     elif args.subcommand == 'db':
         if args.cmd == 'print':
             print(present_addr)
