@@ -87,7 +87,7 @@ def mil(client, code: str) -> dict:
 
     d4, roic = c104.sum_recent_4q('ROIC')
     d5, roe = c104.latest_value('ROE')
-    pcr_dict = c104.find('PCR')
+    pcr_dict = c104.find('PCR', allow_empty=True)
 
     주주수익률 = float('nan') if marketcap == 0 else round((재무활동현금흐름 / marketcap * -100), 2)
     이익지표 = float('nan') if marketcap == 0 else round((지배주주당기순이익 - 영업활동현금흐름) / marketcap, 5)
@@ -176,7 +176,7 @@ def growth(client, code: str) -> dict:
     c104 = C104(client, code, 'c104y')
     c106y = mongo2.C106Y(client, code)
 
-    dict매출액증가율 = c104.find('매출액증가율')
+    dict매출액증가율 = c104.find('매출액증가율', allow_empty=True)
 
     c104.page = 'c104q'
     d1, 매출액증가율 = c104.latest_value('매출액증가율')
