@@ -1,7 +1,7 @@
 import math
 import numpy
 import pprint
-from .db import CorpsEval
+from .db import CorpsEval, C104
 from .eval import EXPECT_EARN, red as eval_red, mil as eval_mil, blue as eval_blue, growth as eval_growth
 
 from db_hj3415 import mongo2
@@ -32,10 +32,7 @@ def red(client, code: str) -> tuple:
         << eval.red() 값 >> \n
         {'red_price': 47896, '사업가치': 7127.5, '재산가치': 7152.78, '부채평가': 902.4, '발행주식수': 27931.0}\n
     """
-    if utils.is_6digit(code):
-        c101 = mongo2.C101(client, code)
-    else:
-        raise ValueError(f'Invalid code: {code}')
+    c101 = mongo2.C101(client, code)
 
     logger.debug(f'c101 {c101.get_recent()}')
 
@@ -108,11 +105,7 @@ def mil(client, code: str) -> tuple:
          '주주수익률': 1.29,
          '투자수익률': {'ROE': -100.94, 'ROIC': -480.97}}
     """
-
-    if utils.is_6digit(code):
-        corps_eval = CorpsEval(client, code)
-    else:
-        raise ValueError(f'Invalid code: {code}')
+    corps_eval = CorpsEval(client, code)
 
     mil_dict = eval_mil(client, code)
 
@@ -210,11 +203,8 @@ def blue(client, code: str) -> tuple:
 
         return int(p)
 
-    if utils.is_6digit(code):
-        corps_eval = CorpsEval(code)
-        c104 = mongo2.C104(client, code, 'c104y')
-    else:
-        raise ValueError(f'Invalid code: {code}')
+    corps_eval = CorpsEval(client, code)
+    c104 = C104(client, code, 'c104y')
 
     blue_dict = eval_blue(client, code)
 
@@ -226,6 +216,8 @@ def blue(client, code: str) -> tuple:
         NEG_MAX = -10
         if math.isnan(유동비율) or 유동비율 <= 0:
             p = NEG_MAX
+        elif math.isinf(유동비율):
+            p = 0
         else:
             p = 0 if 100 < round(유동비율) else NEG_MAX + round(유동비율/10)
         logger.info(f'유동비율평가 point : {p}')
@@ -314,11 +306,7 @@ def growth(client, code: str) -> tuple:
     Returns:
         tuple : 매출액증가율, 영업이익률 평가 포인트
     """
-
-    if utils.is_6digit(code):
-        corps_eval = CorpsEval(client, code)
-    else:
-        raise ValueError(f'Invalid code: {code}')
+    corps_eval = CorpsEval(client, code)
 
     growth_dict = eval_growth(client, code)
 
